@@ -157,8 +157,10 @@
       let charset = null;
       let essence = null;
       let mimeType = null;
-      const headerList = headerListFromHeaders(this[_headers]);
-      const values = getDecodeSplitHeader(headerList, "content-type");
+      const values = getDecodeSplitHeader(
+        headerListFromHeaders(this[_headers]),
+        "Content-Type",
+      );
       if (values === null) return null;
       for (const value of values) {
         const temporaryMimeType = mimesniff.parseMimeType(value);
@@ -230,7 +232,7 @@
       }
       const inner = newInnerResponse(status);
       inner.type = "default";
-      ArrayPrototypePush(inner.headerList, ["location", parsedURL.href]);
+      ArrayPrototypePush(inner.headerList, ["Location", parsedURL.href]);
       const response = webidl.createBranded(Response);
       response[_response] = inner;
       response[_headers] = headersFromHeaderList(
